@@ -475,7 +475,10 @@ def go_(
     job_id = res["job_id"]
     elogger.info(res=res)
 
-    cd = get_challenge_description(token, res["challenge_name"], impersonate=impersonate)
+    if False:
+        cd = get_challenge_description(token, res["challenge_name"], impersonate=impersonate)
+    else:
+        cd = None
 
     cr, uploaded = get_cr(
         res,
@@ -547,7 +550,7 @@ def get_cr(
     allow_host_network: bool,
     use_ipfs: bool,
     server_host: str,
-    cd: ChallengeDescription,
+    cd: Optional[ChallengeDescription],
 ) -> Tuple[ChallengeResults, List]:
     # noinspection PyBroadException
     try:
@@ -604,10 +607,11 @@ def get_cr(
         if aws_config and do_upload:
             try_s3(aws_config)
 
-        if len(cd.steps) == 1:
-            require_scores = set(_.name for _ in cd.scoring.scores)
-        else:
-            require_scores = set()
+        require_scores = set()
+
+        if cd is not None:
+            if len(cd.steps) == 1:
+                require_scores = set(_.name for _ in cd.scoring.scores)
 
         try:
 
